==> seller-config-client-api-4.0.34-20220402.063117-4-sources.jar: com/xforceplus/seller/config/client/api/ConfigTerminalApi.java <==
package com.xforceplus.seller.config.client.api;

import com.xforceplus.seller.config.client.model.*;

import io.swagger.annotations.*;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RequestPart;
import org.springframework.web.multipart.MultipartFile;
import java.util.List;

import javax.validation.constraints.*;
import javax.validation.Valid;


@Api(value = "configTerminal", description = "the configTerminal API")
public interface ConfigTerminalApi {

    @ApiOperation(value = "新增终端", notes = "", response = MsAddTerminalResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "终端新增", response = MsAddTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/addTerminal",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsAddTerminalResponse addTerminal(@ApiParam(value = "终端新增"  ) @RequestBody MsConfigAddTerminalRequest configAddTerminalRequest);


    @ApiOperation(value = "导入终端", notes = "", response = MsResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "统一返回", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/import",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsResponse callImport(@ApiParam(value = "更新终端请求对象" ,required=true ) @RequestBody Object configImportTerminalRequest);


    @ApiOperation(value = "导出终端", notes = "", response = MsResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "统一返回", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/export",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsResponse export(@ApiParam(value = "更新终端请求对象" ,required=true ) @RequestBody Object configExportTerminalRequest);


    @ApiOperation(value = "根据用户权限查询终端", notes = "", response = MsQueryTerminalResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "终端信息获取响应", response = MsQueryTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/getAuthTerminalList",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsQueryTerminalResponse getAuthTerminalList(@ApiParam(value = "查询终端请求对象" ,required=true ) @RequestBody MsConfigTemialAuthQueryRequest configTemialAuthQueryRequest);


    @ApiOperation(value = "查询开票终端", notes = "", response = MsQueryMakeOutTerminalResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "终端信息获取响应", response = MsQueryMakeOutTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/getMakeOutTerminalList",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsQueryMakeOutTerminalResponse getMakeOutTerminalList(@ApiParam(value = "查询开票终端请求对象" ,required=true ) @RequestBody MsConfigTemialQueryMakeOutRequest configTemialQueryMakeOutRequest);


    @ApiOperation(value = "查询终端", notes = "", response = MsQueryTerminalResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "终端信息获取响应", response = MsQueryTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/getTerminalList",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsQueryTerminalResponse getTerminalList(@ApiParam(value = "查询终端请求对象" ,required=true ) @RequestBody MsConfigTemialQueryRequest configTemialQueryRequest);


    @ApiOperation(value = "更新终端信息", notes = "", response = MsResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "统一返回", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/update",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsResponse update(@ApiParam(value = "更新终端请求对象" ,required=true ) @RequestBody MsConfigUpdateTerminalRequest configUpdateTerminalRequest);


    @ApiOperation(value = "更新终端状态", notes = "", response = MsResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "统一返回", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/updateStatus",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsResponse updateStatus(@ApiParam(value = "更新终端状态请求对象" ,required=true ) @RequestBody MsConfigUpdateTerminalStatusRequest configUpdateTerminalStatusRequest);

    @ApiOperation(value = "新获取终端信息", notes = "", response = MsQueryTerminalResponse.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsQueryTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/new/getTerminalList",
            produces = { "application/json" },
            method = RequestMethod.POST)
    MsQueryTerminalResponse getTerminalList(@RequestBody MsQueryTerminalRequest request);
}

==> seller-config-client-api-4.1.30-20250928.033323-2-sources.jar: com/xforceplus/seller/config/client/api/ConfigTerminalApi.java <==
package com.xforceplus.seller.config.client.api;

import com.xforceplus.seller.config.client.model.*;

import com.xforceplus.xplatframework.model.Response;
import io.swagger.annotations.*;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;


@Api(value = "configTerminal", description = "the configTerminal API")
public interface ConfigTerminalApi {

    @ApiOperation(value = "新增终端", notes = "", response = MsAddTerminalResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "终端新增", response = MsAddTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/addTerminal",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsAddTerminalResponse addTerminal(@ApiParam(value = "终端新增"  ) @RequestBody MsConfigAddTerminalRequest configAddTerminalRequest);


    @ApiOperation(value = "导入终端", notes = "", response = MsResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "统一返回", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/import",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsResponse callImport(@ApiParam(value = "更新终端请求对象" ,required=true ) @RequestBody Object configImportTerminalRequest);


    @ApiOperation(value = "导出终端", notes = "", response = MsResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "统一返回", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/export",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsResponse export(@ApiParam(value = "更新终端请求对象" ,required=true ) @RequestBody Object configExportTerminalRequest);


    @ApiOperation(value = "根据用户权限查询终端", notes = "", response = MsQueryTerminalResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "终端信息获取响应", response = MsQueryTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/getAuthTerminalList",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsQueryTerminalResponse getAuthTerminalList(@ApiParam(value = "查询终端请求对象" ,required=true ) @RequestBody MsConfigTemialAuthQueryRequest configTemialAuthQueryRequest);


    @ApiOperation(value = "查询开票终端", notes = "", response = MsQueryMakeOutTerminalResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "终端信息获取响应", response = MsQueryMakeOutTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/getMakeOutTerminalList",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsQueryMakeOutTerminalResponse getMakeOutTerminalList(@ApiParam(value = "查询开票终端请求对象" ,required=true ) @RequestBody MsConfigTemialQueryMakeOutRequest configTemialQueryMakeOutRequest);

    @ApiOperation(value = "查询开票终端设备", notes = "", response = MsResponse.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "终端设备信息获取响应", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/getDeviceList",
            produces = { "application/json" },
            method = RequestMethod.POST)
    MsQueryDeviceResponse getDeviceList(@ApiParam(value = "查询开票终端设备请求对象" ,required=true ) @RequestBody List<String> devcieUnList);

    @ApiOperation(value = "查询终端", notes = "", response = MsQueryTerminalResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "终端信息获取响应", response = MsQueryTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/getTerminalList",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsQueryTerminalResponse getTerminalList(@ApiParam(value = "查询终端请求对象" ,required=true ) @RequestBody MsConfigTemialQueryRequest configTemialQueryRequest);


    @ApiOperation(value = "更新终端信息", notes = "", response = MsResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "统一返回", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/update",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsResponse update(@ApiParam(value = "更新终端请求对象" ,required=true ) @RequestBody MsConfigUpdateTerminalRequest configUpdateTerminalRequest);


    @ApiOperation(value = "更新终端状态", notes = "", response = MsResponse.class, authorizations = {
        @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = { 
        @ApiResponse(code = 200, message = "统一返回", response = MsResponse.class) })
    @RequestMapping(value = "/configTerminal/updateStatus",
        produces = { "application/json" }, 
        method = RequestMethod.POST)
     MsResponse updateStatus(@ApiParam(value = "更新终端状态请求对象" ,required=true ) @RequestBody MsConfigUpdateTerminalStatusRequest configUpdateTerminalStatusRequest);

    @ApiOperation(value = "新获取终端信息", notes = "", response = MsQueryTerminalResponse.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsQueryTerminalResponse.class) })
    @RequestMapping(value = "/configTerminal/new/getTerminalList",
            produces = { "application/json" },
            method = RequestMethod.POST)
    MsQueryTerminalResponse getTerminalList(@RequestBody MsQueryTerminalRequest request);

    @ApiOperation(value = "查询税号全电资质", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = Response.class) })
    @RequestMapping(value = "/configTerminal/query-all-electric-qualification",
            produces = { "application/json" },
            method = RequestMethod.POST)
    Response<AllElectricQualificationData> queryAllElectricQualification(@RequestBody QueryAllElectricQualificationRequest request);

    @ApiOperation(value = "查询开票人信息", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = Response.class) })
    @RequestMapping(value = "/configTerminal/query-all-electric-issuer",
            produces = { "application/json" },
            method = RequestMethod.POST)
    Response<AllElectricIssuerInfoData> queryAllElectricIssuerInfo(@RequestBody QueryAllElectricIssuerInfoRequest request);

    @ApiOperation(value = "查询全电开票人信息列表", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = Response.class) })
    @RequestMapping(value = "/configTerminal/query-all-electric-issuer-list",
            produces = { "application/json" },
            method = RequestMethod.POST)
    Response<List<AllElectricIssuerInfoRecord>> queryAllElectricIssuerInfoList(@RequestBody AllElectricIssuerRequest request);

    @ApiOperation(value = "查询全电开票人信息列表(无过滤)", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = Response.class) })
    @RequestMapping(value = "/configTerminal/query-all-electric-issuer-list-no-filter",
            produces = { "application/json" },
            method = RequestMethod.POST)
    Response<List<AllElectricIssuerInfoRecord>> queryAllElectricIssuerInfosNoFilter(@RequestBody AllElectricIssuerNoFilterRequest request);

    @ApiOperation(value = "分页查询全电开票人信息列表", notes = "", response = Response.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = Response.class) })
    @RequestMapping(value = "/configTerminal/query-electric-issuer-by-page",
            produces = { "application/json" },
            method = RequestMethod.POST)
    Response<AllElectricIssuerInfoResult> queryElectricIssuerInfoByPage(@RequestBody AllElectricIssuerRequest request);

    @ApiOperation(value = "查询租户是否开通数电权限", response = Response.class, authorizations = {
            @Authorization(value = "x-access-token")
    }, tags={ "SellerConfigTemial", })
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = Response.class) })
    @RequestMapping(value = "/configTerminal/query-tenant-qd-ability",
            produces = { "application/json" },
            method = RequestMethod.GET)
    Response<Boolean> queryTenantQdAbility(@RequestParam(value = "tenantId", required = false) Long tenantId);
}
